GoogleSearch_services.doSpellingSuggestionResponseWrapper

|  | ## Cheshire3 Object Model: Class doSpellingSuggestionResponseWrapper

Module GoogleSearch_services :: Class doSpellingSuggestionResponseWrapper

## Class doSpellingSuggestionResponseWrapper
source code

Object Tree:

             TC.TypeCode --+
                           |
       ZSI.TCcompound.Struct --+
                               |
    doSpellingSuggestionResponse --+
                                   |
                                  doSpellingSuggestionResponseWrapper

wrapper for rpc:encoded message
Instance Methods

__init__(self, name=None, ns=None) pyclass -- the Python class to hold the fields ofwhat -- a list of fields to be in the struct hasextras -- ignore extra input fields inorder -- fields must be in exact order or not inline -- don't href/id when serializing mutable -- object could change between multiple serializations type -- the (URI,localname) of the datatype
Inherited from `ZSI.TCcompound.Struct`: `cb`, `parse`, `serialize` Inherited from `ZSI.TC.TypeCode`: `SimpleHREF`, `checkname`, `checktype`, `get_parse_and_errorlist`, `name_match`, `nilled`, `simple_value`

Class Variables

typecode |
Inherited from `ZSI.TC.TypeCode`: `typechecks`

Method Details

### __init__(self, name=None, ns=None) (Constructor) | source code
pyclass -- the Python class to hold the fields ofwhat -- a list of fields to be in the struct hasextras -- ignore extra input fields inorder -- fields must be in exact order or not inline -- don't href/id when serializing mutable -- object could change between multiple serializations type -- the (URI,localname) of the datatype Overrides: doSpellingSuggestionResponse.__init__

Class Variable Details

    ### typecode Value:
        <GoogleSearch_services.doSpellingSuggestionResponse instance at 0xb766\
        b32c>